@@ -40,14 +40,15 @@ from nxtensor.core.types import VariableId, LabelId, MetaDataBlock, Period, DBMe
 import numpy as np
 
 INDEX_NAME = 'index'
-
+PREVIOUS_INDEX = 'previous_index'
 
 METADATA_TYPES = {TimeResolution.DAY: np.int8, TimeResolution.DAY2D: np.str,
                   TimeResolution.HOUR: np.int8, TimeResolution.HOUR2D: np.str,
                   TimeResolution.MONTH: np.int8, TimeResolution.MONTH2D: np.str,
                   TimeResolution.YEAR: np.int16,
                   Coordinate.LAT: np.float64, Coordinate.LON: np.float64,
-                  TensorDimension.LABEL_NUM_ID: np.float64}
+                  TensorDimension.LABEL_NUM_ID: np.float64,
+                  PREVIOUS_INDEX: np.int64}
 
 
 class BlockProcessor(ABC):
@@ -216,7 +217,13 @@ def __build_blocks_structure(dataframe: pd.DataFrame, db_metadata_mapping: DBMet
         raise ConfigurationError(msg, e)
 
     # Add the numerical id of the label.
-    dataframe[TensorDimension.LABEL_NUM_ID] = label_num_id
+    label_num_id_column_name = nu.compute_another_name(TensorDimension.LABEL_NUM_ID,
+                                                       lambda name: name not in dataframe.columns)
+    dataframe[label_num_id_column_name] = label_num_id
+
+    # Add a reference to the current index.
+    previous_index_column_name = nu.compute_another_name(PREVIOUS_INDEX, lambda name: name not in dataframe.columns)
+    dataframe[previous_index_column_name] = dataframe.index
 
     list_keys = TimeResolution.KEYS[0:(resolution_degree + 1)]
     list_column_names = [db_metadata_mapping[key] for key in list_keys]
@@ -233,7 +240,8 @@ def __build_blocks_structure(dataframe: pd.DataFrame, db_metadata_mapping: DBMet
     renamed_df.index.name = INDEX_NAME
     # Select only the columns of interest (lat, lon, year, etc.).
     selected_columns = list(db_metadata_mapping.keys())
-    selected_columns.append(TensorDimension.LABEL_NUM_ID)
+    selected_columns.append(label_num_id_column_name)
+    selected_columns.append(previous_index_column_name)
     restricted_renamed_df = renamed_df[selected_columns]
 
     # Compute the extraction_metadata_blocks.
